@@ -145,8 +145,8 @@ void MainWindow::createMenu()
     actionRight_as_e_mail->setObjectName(QString::fromUtf8("actionRight_as_e_mail"));
     actionAbout_qtranslate = new QAction(this);
     actionAbout_qtranslate->setObjectName(QString::fromUtf8("actionAbout_qtranslate"));
-    actionDonate = new QAction(this);
-    actionDonate->setObjectName(QString::fromUtf8("actionDonate"));
+    //actionDonate = new QAction(this);
+    //actionDonate->setObjectName(QString::fromUtf8("actionDonate"));
 
     QMenuBar * menuBar = new QMenuBar(this);
     menuBar->setObjectName(QString::fromUtf8("menuBar"));
@@ -165,7 +165,7 @@ void MainWindow::createMenu()
     Fremantle->addAction(actionLeft_as_e_mail);
     Fremantle->addAction(actionRight_as_e_mail);
     Fremantle->addAction(actionAbout_qtranslate);
-    Fremantle->addAction(actionDonate);
+    //Fremantle->addAction(actionDonate);
 }
 
 void MainWindow::createComponents()
@@ -289,7 +289,7 @@ void MainWindow::createConnects()
     connect(buttonLeft_clear, SIGNAL(clicked()), this, SLOT(leftClear()));
     connect(buttonRight_clear, SIGNAL(clicked()), this, SLOT(rightClear()));
     connect(actionAbout_qtranslate, SIGNAL(triggered()), this, SLOT(aboutQTranslate()));
-    connect(actionDonate, SIGNAL(triggered()), this, SLOT(donate()));
+    //connect(actionDonate, SIGNAL(triggered()), this, SLOT(donate()));
 
     connect(_accessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(translateRequestFinished(QNetworkReply*)));
 }
@@ -306,7 +306,7 @@ void MainWindow::retranslateUi()
     actionLeft_as_e_mail->setText(QApplication::translate("MainWindow", "Left as e-mail", 0, QApplication::UnicodeUTF8));
     actionRight_as_e_mail->setText(QApplication::translate("MainWindow", "Right as e-mail", 0, QApplication::UnicodeUTF8));
     actionAbout_qtranslate->setText(QApplication::translate("MainWindow", "About qTranslate", 0, QApplication::UnicodeUTF8));
-    actionDonate->setText(QApplication::translate("MainWindow", "Donate", 0, QApplication::UnicodeUTF8));
+    //actionDonate->setText(QApplication::translate("MainWindow", "Donate", 0, QApplication::UnicodeUTF8));
     buttonLeft_clear->setText(QApplication::translate("MainWindow", "Clear", 0, QApplication::UnicodeUTF8));
     buttonRight_clear->setText(QApplication::translate("MainWindow", "Clear", 0, QApplication::UnicodeUTF8));
     Fremantle->setTitle(QApplication::translate("MainWindow", "Fremantle", 0, QApplication::UnicodeUTF8));
@@ -330,11 +330,11 @@ void MainWindow::loadSettings() {
 
 void MainWindow::closeEvent(QCloseEvent *event)
  {
-    //saveSettings();
+    saveSettings();
     event->accept();
  }
 
-void MainWindow::donate()
+/*void MainWindow::donate()
 {
     QMessageBox donate(this);
     donate.setTextFormat(Qt::RichText);
@@ -345,11 +345,11 @@ void MainWindow::donate()
     int ret = donate.exec();
     if (ret == QMessageBox::Yes)
         QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=VXN9T26P6HVLG"));
-}
+}*/
 
 void MainWindow::aboutQTranslate()
 {
-    QMessageBox::information(this, tr("About qTranslate"),tr("qTranslate was developed by <a href=\"http://www.peterbouda.de\">Peter Bouda</a>. All rights reserverd. Contact me for development of Qt software and Ruby on Rails web applications: contact@peterbouda.de<br/>Get a free wiki at <a href=\"http://aufundapp.de/tor\">Tiddler on Rails</a>. Access it everywhere."));
+    QMessageBox::information(this, tr("About qTranslate"),tr("qTranslate - A translation software for Maemo, Symbian and MeeGo<br>v1.0.0<br>based on Google Translate<br>Find more information and support us on <a href=\"http://mobileqt.de/apps/qtranslate\">the qTranslate website</a>"));
 }
 
 void MainWindow::leftClear()
@@ -527,62 +527,61 @@ void MainWindow::createLangCodes()
 {
     QMap<QString, QString> langCodes;
 
-    langCodes["af"] = "Afrikaans";
-    langCodes["sq"] = "Albanian";
-    langCodes["ar"] = "Arabic";
-    langCodes["bg"] = "Bulgarian";
-    langCodes["ca"] = "Catalan";
-    langCodes["zh-CN"] = "Chinese";
-    langCodes["hr"] = "Croatian";
-    langCodes["cs"] = "Czech";
-    langCodes["nl"] = "Dutch";
-    langCodes["en"] = "English";
-    langCodes["et"] = "Estonian";
-    langCodes["fa"] = "Farsi";
-    langCodes["fi"] = "Finnish";
-    langCodes["fr"] = "French";
-    langCodes["gl"] = "Galician";
-    langCodes["de"] = "German";
-    langCodes["el"] = "Greek";
-    langCodes["iw"] = "Hebrew";
-    langCodes["hi"] = "Hindi";
-    langCodes["hu"] = "Hungarian";
-    langCodes["is"] = "Icelandic";
-    langCodes["id"] = "Indonesian";
-    langCodes["ga"] = "Irish";
-    langCodes["it"] = "Italian";
-    langCodes["ja"] = "Japanese";
-    langCodes["ko"] = "Korean";
-    langCodes["lv"] = "Lettic";
-    langCodes["lt"] = "Lithuanian";
-    langCodes["mk"] = "Macedonian";
-    langCodes["ms"] = "Malay";
-    langCodes["mt"] = "Maltese";
-    langCodes["no"] = "Norwegian";
-    langCodes["pl"] = "Polish";
-    langCodes["pt"] = "Portuguese";
-    langCodes["ro"] = "Romanian";
-    langCodes["ru"] = "Russian";
-    langCodes["sr"] = "Serbian";
-    langCodes["sk"] = "Slovakian";
-    langCodes["sl"] = "Slovenian";
-    langCodes["es"] = "Spanish";
-    langCodes["sw"] = "Swahili";
-    langCodes["sv"] = "Swedish";
-    langCodes["tl"] = "Tagalog";
-    langCodes["th"] = "Thai";
-    langCodes["tr"] = "Turkish";
-    langCodes["uk"] = "Ukrainian";
-    langCodes["vi"] = "Vietnamese";
-    langCodes["cy"] = "Welsh";
-    langCodes["yi"] = "Yiddish";
-
+    langCodes[tr("Afrikanns")] = "af";
+    langCodes[tr("Albanian")] = "sq";
+    langCodes[tr("Arabic")] = "ar";
+    langCodes[tr("Bulgarian")] = "bg";
+    langCodes[tr("Catalan")] = "ca";
+    langCodes[tr("Chinese")] = "zh-CN";
+    langCodes[tr("Croatian")] = "hr";
+    langCodes[tr("Czech")] = "cs";
+    langCodes[tr("Dutch")] = "nl";
+    langCodes[tr("English")] = "en";
+    langCodes[tr("Estonian")] = "et";
+    langCodes[tr("Farsi")] = "fa";
+    langCodes[tr("Finnish")] = "fi";
+    langCodes[tr("French")] = "fr";
+    langCodes[tr("Galician")] = "gl";
+    langCodes[tr("German")] = "de";
+    langCodes[tr("Greek")] = "el";
+    langCodes[tr("Hebrew")] = "iw";
+    langCodes[tr("Hindi")] = "hi";
+    langCodes[tr("Hungarian")] = "hu";
+    langCodes[tr("Icelandic")] = "is";
+    langCodes[tr("Indonesian")] = "id";
+    langCodes[tr("Irish")] = "ga";
+    langCodes[tr("Italian")] = "it";
+    langCodes[tr("Japanese")] = "ja";
+    langCodes[tr("Korean")] = "ko";
+    langCodes[tr("Lettic")] = "lv";
+    langCodes[tr("Lithuanian")] = "lt";
+    langCodes[tr("Macedonian")] = "mk";
+    langCodes[tr("Malay")] = "ms";
+    langCodes[tr("Maltese")] = "mt";
+    langCodes[tr("Norwegian")] = "no";
+    langCodes[tr("Polish")] = "pl";
+    langCodes[tr("Portuguese")] = "pt";
+    langCodes[tr("Romanian")] = "ro";
+    langCodes[tr("Russian")] = "ru";
+    langCodes[tr("Serbian")] = "sr";
+    langCodes[tr("Slovakian")] = "sk";
+    langCodes[tr("Slovenian")] = "sl";
+    langCodes[tr("Spanish")] = "es";
+    langCodes[tr("Swahili")] = "sw";
+    langCodes[tr("Swedish")] = "sv";
+    langCodes[tr("Tagalog")] = "tl";
+    langCodes[tr("Thai")] = "th";
+    langCodes[tr("Turkish")] = "tr";
+    langCodes[tr("Ukrainian")] = "uk";
+    langCodes[tr("Vietnamese")] = "vi";
+    langCodes[tr("Welsh")] = "cy";
+    langCodes[tr("Yiddish")] = "yi";
 
     QMapIterator<QString, QString> i(langCodes);
     while (i.hasNext()) {
          i.next();
-         comboboxLang_left->addItem(i.value(), i.key());
-         comboboxLang_right->addItem(i.value(), i.key());
+         comboboxLang_left->addItem(i.key(), i.value());
+         comboboxLang_right->addItem(i.key(), i.value());
     }
 }
 
