@@ -30,7 +30,7 @@ public slots:
     void translateLeftToRight();
     void translateRightToLeft();
     void aboutQTranslate();
-    void donate();
+    //void donate();
 
 protected:
     void changeEvent(QEvent *e);
@@ -67,7 +67,7 @@ private:
     QAction *actionLeft_as_e_mail;
     QAction *actionRight_as_e_mail;
     QAction *actionAbout_qtranslate;
-    QAction *actionDonate;
+    //QAction *actionDonate;
 
     QTextEdit *texteditLeft;
     QTextEdit *texteditRight;
